# polars-error

`polars-error` is an **internal sub-crate** of the [Polars](https://crates.io/crates/polars) library, defining its error types.

**Important Note**: This crate is **not intended for external usage**. Please refer to the main [Polars crate](https://crates.io/crates/polars) for intended usage.
